@@ -8,7 +8,7 @@ use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
 use Data::Dumper::Concise; # For Dumper();
 use Data::Section::Simple 'get_data_section';
 
-use File::Glob ':bsd_glob';
+use File::Glob ':glob';
 use File::Slurper 'read_lines';
 
 use Log::Handler;
@@ -111,7 +111,7 @@ has stack =>
 
 my($myself); # For use inside functions.
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 # -----------------------------------------------
 
@@ -215,12 +215,13 @@ sub file_glob
 
 	$myself -> log(debug => "'$name' matched '$match'");
 
-	# Warning! Do not use (sort bsd_glob($match) ),
-	# when bs_glob() returns the unglobbed 'colors/*s*.png'.
-	# You can use (sort map{$_} bsd_glob($match) )
-	# but the result is ASCII sorted (by default) anyway.
+	# Warning! Do not use (sort bsd_glob($match) ), when bs_glob() returns the unglobbed 'colors/*s*.png'.
+	# You can use (sort map{$_} bsd_glob($match) ) but the result is ASCII sorted (by default) anyway.
+	# Note for V 1.01. I've reverted to just glob in the use statement, since bsd_glob was only introduced
+	# in Perl V 5.16. And note that I use glob in list context, not the dangerous scalar context.
+	# That's why test 47 works.
 
-	for my $file (bsd_glob($match) )
+	for my $file (glob($match) )
 	{
 		$myself -> stack -> push
 		({
